@@ -136,8 +136,6 @@ public Q_SLOTS:
 
     void applicationAboutToQuit();
 
-    void showConfiguration();
-
     void setElisaApplication(ElisaApplication* elisaApplication);
 
     void playBackError(const QUrl &sourceInError, QMediaPlayer::Error playerError);
@@ -148,6 +146,8 @@ public Q_SLOTS:
 
     void resetMusicData();
 
+    void updateSingleFileMetaData(const QUrl &url, DataTypes::ColumnsRoles role, const QVariant &data);
+
 private Q_SLOTS:
 
     void configChanged();
